summaryrefslogtreecommitdiffstats
path: root/kwin/clients/modernsystem/config/config.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/clients/modernsystem/config/config.cpp')
-rw-r--r--kwin/clients/modernsystem/config/config.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kwin/clients/modernsystem/config/config.cpp b/kwin/clients/modernsystem/config/config.cpp
index f5260ba7d..136ff3492 100644
--- a/kwin/clients/modernsystem/config/config.cpp
+++ b/kwin/clients/modernsystem/config/config.cpp
@@ -19,16 +19,16 @@ extern "C"
}
// 'conf' is a pointer to the kwindecoration modules open kwin config,
// and is by default set to the "Style" group.
//
// 'parent' is the parent of the TQObject, which is a VBox inside the
-// Configure tab in kwindecoration
+// Configure tab in twindecoration
ModernSysConfig::ModernSysConfig(KConfig* conf, TQWidget* parent) : TQObject(parent)
{
- clientrc = new KConfig("kwinmodernsysrc");
- KGlobal::locale()->insertCatalogue("kwin_clients");
+ clientrc = new KConfig("twinmodernsysrc");
+ KGlobal::locale()->insertCatalogue("twin_clients");
mainw = new TQWidget(parent);
vbox = new TQVBoxLayout(mainw);
vbox->setSpacing(6);
@@ -19,16 +19,16 @@ extern "C"
}
-// 'conf' is a pointer to the kwindecoration modules open kwin config,
+// 'conf' is a pointer to the twindecoration modules open twin config,
// and is by default set to the "Style" group.
//